@@ -1,5 +1,5 @@
 fn main() {
-    #[cfg(not(feature = "tracing-gstreamer-docs"))]
+    #[cfg(not(tracing_gstreamer_docs))]
     if let Err(e) = pkg_config::Config::new().probe("gstreamer-1.0") {
         eprintln!("error: {}", e);
         std::process::exit(1);
